@@ -700,7 +700,15 @@ impl<'a> DataNodeRef<'a> {
         match self.schema().kind() {
             SchemaNodeKind::Leaf | SchemaNodeKind::LeafList => {
                 let rnode = self.raw as *mut ffi::lyd_node_term;
-                let value = unsafe { (*rnode).value._canonical };
+                let mut value = unsafe { (*rnode).value._canonical };
+                if value.is_null() {
+                    value = unsafe {
+                        ffi::lyd_value_get_canonical(
+                            self.context().raw,
+                            &(*rnode).value,
+                        )
+                    };
+                }
                 char_ptr_to_opt_string(value)
             }
             _ => None,
@@ -899,6 +907,25 @@ unsafe impl Sync for Metadata<'_> {}
 // ===== impl DataDiff =====
 
 impl DataDiff {
+    /// Parse (and validate) input data as a YANG data diff.
+    pub fn parse_string(
+        context: &Arc<Context>,
+        data: &str,
+        format: DataFormat,
+        parser_options: DataParserFlags,
+        validation_options: DataValidationFlags,
+    ) -> Result<DataDiff> {
+        let dtree = DataTree::parse_string(
+            context,
+            data,
+            format,
+            parser_options,
+            validation_options,
+        )?;
+
+        Ok(DataDiff { tree: dtree })
+    }
+
     /// Returns an iterator over the data changes.
     pub fn iter(&self) -> impl Iterator<Item = (DataDiffOp, DataNodeRef<'_>)> {
         self.tree.traverse().filter_map(|dnode| {
